﻿using Connected.Utilities;
using Microsoft.AspNetCore.Components;
using Microsoft.AspNetCore.Components.Web;

namespace Connected.ComponentsN;
public partial class Button
{
    /// <summary>
    /// Text shown inside the button
    /// </summary>
    [Parameter]
    public string Text { get; set; } = string.Empty;

    [Parameter]
    /// <summary>
    /// Button click event.
    /// </summary>
    public EventCallback<MouseEventArgs> Click { get; set; }
    protected async Task OnClick(MouseEventArgs e)
    {
        await Click.InvokeAsync(e);

    }
    /// <summary>
    /// Disabled or enabled property of the button. Default: false
    /// </summary>
    [Parameter]
    public bool Disabled { get; set; } = false;

    /// <summary>
    /// Glyph for the button. 
    /// Default: string.Empty
    /// </summary>
    [Parameter]
    public string Glyph { get; set; } = string.Empty;

    /// <summary>
    /// Position of the glyph relative to button Text parameter. Default: GlyphPosition.LEFT (Possible options: GlyphPosition.LEFT, GlyphPosition.TOP, GlyphPosition.RIGHT, GlyphPosition.BOTTOM)
    /// If Glyph parameter is empty this parameter is ignored
    /// </summary>
    [Parameter]
    public Position GlyphPosition { get; set; } = Position.Left;

    /// <summary>
    /// HEX value of the color for the glyph custom color. Default: black (#000000)
    /// If Glyph parameter is empty this parameter is ignored
    /// </summary>
    [Parameter]
    public string GlyphColor { get; set; } = "#000000";

    [Parameter]
    public string Class { get; set; } = string.Empty;

    private string ButtonClassList
    {
        get
        {
            return new CssBuilder()
                .AddClass(Class)
                .Build();
        }
    }

    [Parameter]
    public string Style { get; set; } = string.Empty;

    private string ButtonStyleList
    {
        get
        {
            return new StyleBuilder()
                .AddStyle(Style)
                .Build();
        }
    }

	/// <summary>
	/// When mouse is over the component
	/// </summary>
	/// <returns></returns>
	public async Task HoverOn()
	{
	}

	/// <summary>
	/// When mouse is away from component
	/// </summary>
	/// <returns></returns>
	public async Task HoverOff()
	{
	}
}
