﻿using Connected.Utilities;
using Microsoft.AspNetCore.Components;

namespace Connected.ComponentsN;
public partial class InputNumber<Type>
{
    #region parameters
    /// <summary>
    /// Class 
    /// </summary>
    [Parameter]
    public string Class { get; set; }

    private string InputFieldClassList
    {
        get
        {
            return new CssBuilder()
                .AddClass(Class)
                .Build();
        }
    }

    /// <summary>
    /// Type of the input element. It should be a valid HTML5 input type.
    /// </summary>
    private InputType InputType { get; set; } = InputType.Number;

    /// <summary>
    /// Show clear button.
    /// </summary>
    [Parameter]
    public bool ShowClearButton { get; set; } = false;

    /// <summary>
    /// The show input character counter
    /// </summary>
    [Parameter]
    public bool ShowCharacterCounter { get; set; }

    [Parameter]
    public string ErrorText { get; set; } = string.Empty;

    [Parameter]
    public string Label { get; set; } = string.Empty;

    /// <summary>
    /// Step of Numeric field up/down. Only used when InputType.Number is used 
    /// </summary>
    [Parameter]
    public double Step { get; set; } = 1;

    #endregion

    #region Variables
    private string _clearIcon = Icons.Material.Filled.Clear;

    #endregion

    [Parameter]
    public Type Value { get; set; }

    [Parameter]
    public EventCallback<Type> ValueChanged { get; set; }

    private async Task ChangeValueAsync(ChangeEventArgs args)
    {
        Type param = (Type)Convert.ChangeType(args.Value, typeof(Type));


        await ValueChanged.InvokeAsync(param);
    }

    #region Lifecycle

    #endregion
}
