﻿
using Connected.Utilities;
using Microsoft.AspNetCore.Components;

namespace Connected.ComponentsN;
public partial class InputText
{
    #region parameters
    /// <summary>
    /// Class 
    /// </summary>
    [Parameter]
    public string Class { get; set; }

    private string InputFieldClassList
    {
        get
        {
            return new CssBuilder()
                .AddClass(Class)
                .Build();
        }
    }

    private InputType InputType { get; set; } = InputType.Text;

    [Parameter]
    public bool IsPasswordField { get; set; } = false;

    /// <summary>
    /// Show clear button.
    /// </summary>
    [Parameter]
    public bool Clearable { get; set; } = false;

    /// <summary>
    /// Required property
    /// </summary>
    [Parameter]
    public bool Required { get; set; } = false;

    /// <summary>
    /// Show clear button.
    /// </summary>
    [Parameter]
    public bool Disabled { get; set; } = false;

    /// <summary>
    /// Show clear button.
    /// </summary>
    [Parameter]
    public bool Readonly { get; set; } = false;

    /// <summary>
    /// The show input character counter
    /// </summary>
    [Parameter]
    public bool ShowCharCounter { get; set; }

    [Parameter]
    public string ErrorText { get; set; } = string.Empty;

    [Parameter]
    public string Label { get; set; } = string.Empty;

    [Parameter]
    public string Placeholder { get; set; } = string.Empty;


    /// <summary>
    /// If more than 1, we have a textarea with defined number of lines
    /// </summary>
    [Parameter]
    public int NumOfLines
    {
        get
        {
            return _numberOfLines;
        }
        set
        {
            if (value < 1)
            {
                _numberOfLines = 1;
            }
            else
            {
                _numberOfLines = value;
            }
        }
    }
    private int _numberOfLines = 1;

    #endregion

    #region Variables
    private string _clearIcon = Icons.Material.Filled.Clear;

    #endregion

    [Parameter]
    public string Value { get; set; }

    [Parameter]
    public EventCallback<string> ValueChanged { get; set; }

    private async Task ChangeValueAsync(ChangeEventArgs args)
    {

        await ValueChanged.InvokeAsync(args.Value.ToString());
    }

    #region Lifecycle

    protected async Task OnParametersSetAsync()
    {
        if (IsPasswordField) InputType = InputType.Password;


        await base.OnParametersSetAsync();
    }

    #endregion
}