﻿using Connected.Utilities;
using Microsoft.AspNetCore.Components;
using Microsoft.AspNetCore.Components.Web;

namespace Connected.ComponentsN;
public partial class ToggleButton
{
	/// <summary>
	/// Define state of ToggleButton: Default: false
	/// </summary>
	[Parameter]
	public bool Toggled { get; set; } = false;

	private void Toggle()
	{
		Toggled=!Toggled;
		StateHasChanged();
	}

	#region Text content
	/// <summary>
	/// default Text shown inside the button
	/// </summary>
	[Parameter]
    public string Text { get; set; } = string.Empty;
	/// <summary>
	/// Text of toggled button shown inside the button
	/// </summary>
	[Parameter]
	public string ToggleText { get; set; } = string.Empty;

	private string TextToShow()
	{
		if (Toggled) return ToggleText;
		return Text;
	}

	#endregion

	#region Glyph
	/// <summary>
	/// Glyph for the button. 
	/// Default: string.Empty
	/// </summary>
	[Parameter]
	public string Glyph { get; set; } = string.Empty;

	/// <summary>
	/// Glyph for the button. 
	/// Default: string.Empty
	/// </summary>
	[Parameter]
	public string ToggleGlyph { get; set; } = string.Empty;

	private string GlyphToShow()
	{
		if (Toggled) return ToggleGlyph;
		return Glyph;
	}

	/// <summary>
	/// Position of the glyph relative to button Text parameter. Default: Position.Left (Possible options: Top,Bottom,Center,Left,Right,Start,End)
	/// If Glyph parameter is empty this parameter is ignored
	/// </summary>
	[Parameter]
	public Position GlyphPosition { get; set; } = Position.Left;

	/// <summary>
	/// HEX value of the color for the glyph custom color. Default: black (#000000)
	/// If Glyph parameter is empty this parameter is ignored
	/// </summary>
	[Parameter]
	public string GlyphColor { get; set; } = "#000000";

	/// <summary>
	/// HEX value of the color for the glyph custom color. Default: black (#000000)
	/// If Glyph parameter is empty this parameter is ignored
	/// </summary>
	[Parameter]
	public string ToggleGlyphColor { get; set; } = "#000000";

	private string GlyphColorToUse()
	{
		if (Toggled) return ToggleGlyphColor;
		return GlyphColor;
	}

	#endregion


	[Parameter]
    /// <summary>
    /// Button click event.
    /// </summary>
    public EventCallback<MouseEventArgs> Click { get; set; }
    protected async Task OnClick(MouseEventArgs e)
    {
        await Click.InvokeAsync(e);
    }

    /// <summary>
    /// Disabled or enabled property of the button. Default: false
    /// </summary>
    [Parameter]
    public bool Disabled { get; set; } = false;

    [Parameter]
    public string Class { get; set; } = string.Empty;

    private string ButtonClassList
    {
        get
        {
            return new CssBuilder()
                .AddClass(Class)
                .Build();
        }
    }

    [Parameter]
    public string Style { get; set; } = string.Empty;

    private string ButtonStyleList
    {
        get
        {
            return new StyleBuilder()
                .AddStyle(Style)
                .Build();
        }
    }

	/// <summary>
	/// When mouse is over the component
	/// </summary>
	/// <returns></returns>
	public async Task HoverOn()
	{
	}

	/// <summary>
	/// When mouse is away from component
	/// </summary>
	/// <returns></returns>
	public async Task HoverOff()
	{
	}
}
